==> zio-aws-proton_2.13-5.17.130.2-sources.jar: zio/aws/proton/model/ListEnvironmentProvisionedResourcesResponse.scala <==
package zio.aws.proton.model
import zio.aws.proton.model.primitives.EmptyNextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListEnvironmentProvisionedResourcesResponse(
    nextToken: Option[EmptyNextToken] = None,
    provisionedResources: Iterable[zio.aws.proton.model.ProvisionedResource]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.proton.model.ListEnvironmentProvisionedResourcesResponse = {
    import ListEnvironmentProvisionedResourcesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.proton.model.ListEnvironmentProvisionedResourcesResponse
      .builder()
      .optionallyWith(
        nextToken.map(value => EmptyNextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .provisionedResources(provisionedResources.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .build()
  }
  def asReadOnly
      : zio.aws.proton.model.ListEnvironmentProvisionedResourcesResponse.ReadOnly =
    zio.aws.proton.model.ListEnvironmentProvisionedResourcesResponse
      .wrap(buildAwsValue())
}
object ListEnvironmentProvisionedResourcesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.proton.model.ListEnvironmentProvisionedResourcesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.proton.model.ListEnvironmentProvisionedResourcesResponse =
      zio.aws.proton.model.ListEnvironmentProvisionedResourcesResponse(
        nextToken.map(value => value),
        provisionedResources.map { item =>
          item.asEditable
        }
      )
    def nextToken: Option[EmptyNextToken]
    def provisionedResources
        : List[zio.aws.proton.model.ProvisionedResource.ReadOnly]
    def getNextToken: ZIO[Any, AwsError, EmptyNextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getProvisionedResources: ZIO[Any, Nothing, List[
      zio.aws.proton.model.ProvisionedResource.ReadOnly
    ]] = ZIO.succeed(provisionedResources)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.proton.model.ListEnvironmentProvisionedResourcesResponse
  ) extends zio.aws.proton.model.ListEnvironmentProvisionedResourcesResponse.ReadOnly {
    override val nextToken: Option[EmptyNextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.proton.model.primitives.EmptyNextToken(value))
    override val provisionedResources
        : List[zio.aws.proton.model.ProvisionedResource.ReadOnly] = impl
      .provisionedResources()
      .asScala
      .map { item =>
        zio.aws.proton.model.ProvisionedResource.wrap(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.proton.model.ListEnvironmentProvisionedResourcesResponse
  ): zio.aws.proton.model.ListEnvironmentProvisionedResourcesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-proton_2.13-5.17.295.19-sources.jar: zio/aws/proton/model/ListEnvironmentProvisionedResourcesResponse.scala <==
package zio.aws.proton.model
import zio.aws.proton.model.primitives.EmptyNextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListEnvironmentProvisionedResourcesResponse(
    nextToken: Optional[EmptyNextToken] = Optional.Absent,
    provisionedResources: Iterable[zio.aws.proton.model.ProvisionedResource]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.proton.model.ListEnvironmentProvisionedResourcesResponse = {
    import ListEnvironmentProvisionedResourcesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.proton.model.ListEnvironmentProvisionedResourcesResponse
      .builder()
      .optionallyWith(
        nextToken.map(value => EmptyNextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .provisionedResources(provisionedResources.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .build()
  }
  def asReadOnly
      : zio.aws.proton.model.ListEnvironmentProvisionedResourcesResponse.ReadOnly =
    zio.aws.proton.model.ListEnvironmentProvisionedResourcesResponse
      .wrap(buildAwsValue())
}
object ListEnvironmentProvisionedResourcesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.proton.model.ListEnvironmentProvisionedResourcesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.proton.model.ListEnvironmentProvisionedResourcesResponse =
      zio.aws.proton.model.ListEnvironmentProvisionedResourcesResponse(
        nextToken.map(value => value),
        provisionedResources.map { item =>
          item.asEditable
        }
      )
    def nextToken: Optional[EmptyNextToken]
    def provisionedResources
        : List[zio.aws.proton.model.ProvisionedResource.ReadOnly]
    def getNextToken: ZIO[Any, AwsError, EmptyNextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getProvisionedResources: ZIO[Any, Nothing, List[
      zio.aws.proton.model.ProvisionedResource.ReadOnly
    ]] = ZIO.succeed(provisionedResources)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.proton.model.ListEnvironmentProvisionedResourcesResponse
  ) extends zio.aws.proton.model.ListEnvironmentProvisionedResourcesResponse.ReadOnly {
    override val nextToken: Optional[EmptyNextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.proton.model.primitives.EmptyNextToken(value))
    override val provisionedResources
        : List[zio.aws.proton.model.ProvisionedResource.ReadOnly] = impl
      .provisionedResources()
      .asScala
      .map { item =>
        zio.aws.proton.model.ProvisionedResource.wrap(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.proton.model.ListEnvironmentProvisionedResourcesResponse
  ): zio.aws.proton.model.ListEnvironmentProvisionedResourcesResponse.ReadOnly =
    new Wrapper(impl)
}
